summaryrefslogtreecommitdiffstats
path: root/content/renderer/pepper_plugin_delegate_impl.h
diff options
context:
space:
mode:
Diffstat (limited to 'content/renderer/pepper_plugin_delegate_impl.h')
-rw-r--r--content/renderer/pepper_plugin_delegate_impl.h4
1 files changed, 3 insertions, 1 deletions
diff --git a/content/renderer/pepper_plugin_delegate_impl.h b/content/renderer/pepper_plugin_delegate_impl.h
index 22de0d5..1cba5eb 100644
--- a/content/renderer/pepper_plugin_delegate_impl.h
+++ b/content/renderer/pepper_plugin_delegate_impl.h
@@ -151,7 +151,9 @@ class PepperPluginDelegateImpl
bool* pepper_plugin_was_registered);
// Called by RenderView to tell us about painting events, these two functions
- // just correspond to the DidInitiatePaint and DidFlushPaint in R.V..
+ // just correspond to the WillInitiatePaint, DidInitiatePaint and
+ // DidFlushPaint hooks in RenderView.
+ void ViewWillInitiatePaint();
void ViewInitiatedPaint();
void ViewFlushedPaint();